@@ -10,15 +10,13 @@ class Server:
         self.conn = None
         self.addr = None
         self.usbport = usbport
-        try:
-            self.serial = serial.serial(self.usbport,9600)
-        except:
-            print("connct arduino properly")
-
+        self.serial = None
+       
     def create(self):
         """This create a Server and bind it with host and ip address """
         try:
             self.s = socket.socket()
+            self.serial = serial.serial(self.usbport,9600)
         except socket.error as msg:
             print("Creation error "+msg)
         while True:
